@@ -1,6 +1,6 @@
 #' Show logos of the packages inside SIPDIBGE
 #' @description This function shows the survey logos of the packages inside SIPDIBGE.
-#' @import COVIDIBGE PNADcIBGE PNSIBGE cli graphics grDevices png purrr rstudioapi tibble utils
+#' @import COVIDIBGE PNADcIBGE PNDSIBGE PNSIBGE cli graphics grDevices png purrr rstudioapi tibble utils
 #' @param survey Name of the household survey for reference package information. If \code{NULL}, shows the logos of all the packages inside this collection, including the SIPD logo.
 #' @return An image with the logos required of the packages inside SIPDIBGE.
 #' @note For more information, visit the survey official website <\url{https://www.ibge.gov.br/}> and consult the other functions of this package, described below.
@@ -40,7 +40,7 @@ sipd_logo <- function(survey = NULL) {
     graphics::rasterImage(logo,0,0,1,1)
   }
   else if (toupper(survey) == "PNDS") {
-    message("The PNDSIBGE package is under development and will be available soon.")
+    message("The PNDSIBGE package is under development and will be available soon.\n")
     return(NULL)
     grDevices::dev.new()
     graphics::plot.new()
@@ -54,7 +54,7 @@ sipd_logo <- function(survey = NULL) {
     graphics::rasterImage(logo,0,0,1,1)
   }
   else if (toupper(survey) == "POF") {
-    message("The POFIBGE package was archived due to the impossibility of restructuring the files related to the survey microdata.")
+    message("The POFIBGE package was archived due to the impossibility of restructuring the files related to the survey microdata.\n")
     return(NULL)
     grDevices::dev.new()
     graphics::plot.new()
