@@ -1,6 +1,6 @@
 #' Indicate version information of the packages inside SIPDIBGE
 #' @description This function describes version information of the packages inside SIPDIBGE.
-#' @import COVIDIBGE PNADcIBGE PNSIBGE cli graphics grDevices png purrr rstudioapi tibble utils
+#' @import COVIDIBGE PNADcIBGE PNDSIBGE PNSIBGE cli graphics grDevices png purrr rstudioapi tibble utils
 #' @param survey Name of the household survey for reference package information. If \code{NULL}, presents the information of all the packages inside this collection.
 #' @return A vector with version information of the packages inside SIPDIBGE.
 #' @note For more information, visit the survey official website <\url{https://www.ibge.gov.br/}> and consult the other functions of this package, described below.
@@ -53,7 +53,7 @@ sipd_sitrep <- function(survey = NULL) {
     infos <- tibble::tibble(package=deps, cran=cran %>% purrr::map_chr(as.character), local=local %>% purrr::map_chr(as.character), former=former)
   }
   else if (toupper(survey) == "PNDS") {
-    message("The PNDSIBGE package is under development and will be available soon.")
+    message("The PNDSIBGE package is under development and will be available soon.\n")
     return(NULL)
     deps <- unique(sort(c("PNDSIBGE", unlist(SIPDIBGE::sipd_deps(survey="PNDS")))))
     base <- c("base", "compiler", "datasets", "graphics", "grDevices", "grid", "methods", "parallel", "splines", "stats", "stats4", "tools", "tcltk", "utils")
@@ -77,7 +77,7 @@ sipd_sitrep <- function(survey = NULL) {
     infos <- tibble::tibble(package=deps, cran=cran %>% purrr::map_chr(as.character), local=local %>% purrr::map_chr(as.character), former=former)
   }
   else if (toupper(survey) == "POF") {
-    message("The POFIBGE package was archived due to the impossibility of restructuring the files related to the survey microdata.")
+    message("The POFIBGE package was archived due to the impossibility of restructuring the files related to the survey microdata.\n")
     return(NULL)
     deps <- unique(sort(c("POFIBGE", unlist(SIPDIBGE::sipd_deps(survey="POF")))))
     base <- c("base", "compiler", "datasets", "graphics", "grDevices", "grid", "methods", "parallel", "splines", "stats", "stats4", "tools", "tcltk", "utils")
